<?php
/*********************************************************************************
 ** The contents of this file are subject to the vtiger CRM Public License Version 1.0
  * ("License"); You may not use this file except in compliance with the License
  * The Original Code is:  vtiger CRM Open Source
  * The Initial Developer of the Original Code is vtiger.
  * Portions created by vtiger are Copyright (C) vtiger.
  * All Rights Reserved.
  ********************************************************************************/
$app_strings = array (
	'Groups'=>'Gruppen',
	'DocumentFolders'=>'Dokumentenverzeichnisse',
	'Currency'=>'Währung',
	'SINGLE_Groups'=>'Gruppe',
	'SINGLE_DocumentFolders'=>'Dokumentenverzeichnis',
	'SINGLE_Currency'=>'Währung',
);

$webservice_strings = array(
	'LBL_INVALID_OLD_PASSWORD' => 'Ungültige Angabe des alten Passwortes.',
	'LBL_NEW_PASSWORD_MISMATCH' => "Die beiden Passwörter stimmen nicht überein.",
	'LBL_DATABASE_QUERY_ERROR' => 'Ihre Anfrage konnte aufgrund eines Datenbankfehlers nicht verarbeitet werden.',
	'LBL_CHANGE_PASSWORD_FAILURE' => 'Passwort konnte nicht geändert werden.Failed to change password',
);
?>